import { useState } from 'react'
import { FieldType, IStock } from '../Interfaces/Stock'
import { FormProps, Row, Table, Typography } from 'antd'
import { columns } from '../data/Stock';
import StockForm from '../Components/StockForm';

const Stock = () => {
    const [items, setItems] = useState<IStock[]>([
        {title: 'Acer', price: 1000, count: 2},
        {title: 'Lenova', price: 2000, count: 1}
    ])

    const minusHandler = (title: string) => {
        const index = items.findIndex(item => item.title === title)
        const copyItems = [...items]
        copyItems[index].count--
        
        if(copyItems[index].count >= 0) setItems(copyItems)
    }

    const onFinish: FormProps<FieldType>['onFinish'] = (values) => {
        const copyItems = [...items]
        copyItems.push(values)
        setItems(copyItems)
    };

    const isItems = items.map(item => item.count).reduce((a, b) => a + b, 0)

    return (
        <Row style={{height: '100%', width: '100%', flexDirection: 'column'}}>
            <Row justify={'center'}>
                {
                    isItems > 0 ? 
                    <Table
                        columns={columns({onClick: minusHandler})}
                        dataSource={items}
                        style={{width: '80%'}}
                    />
                    :
                    <Typography.Title>
                        No Products
                    </Typography.Title>
                }
            </Row>
            <Row justify={'center'}>
                <StockForm
                    onFinish={onFinish}
                />
            </Row>
        </Row>
    )
}

export default Stock