import { TableColumnsType, Button } from "antd";
import { MinusOutlined } from "@ant-design/icons"
import { IStock } from "../Interfaces/Stock";

type TProps = {
    onClick: (title: string) => void
}

export const columns = ({onClick}: TProps): TableColumnsType<IStock> => {
    return [
        {   
            key: 'title',
            title: 'Title',
            dataIndex: 'title',
            sorter: (a, b) => a.title.length - b.title.length,
        },
        {
            key: 'price',
            title: 'Price',
            dataIndex: 'price',
            sorter: (a, b) => a.price - b.price,
        },
        {
            key: 'count',
            title: 'Count',
            dataIndex: 'count',
            sorter: (a, b) => a.count - b.count,
            render: (val) => {
                return val === 0 ? 'Not avalible' : val
            }
        },
        {
            key: 'action',
            title: 'Action',
            dataIndex: 'action',
            render: (_, record) => {
                return (
                    <Button 
                        danger
                        type={'primary'}
                        icon={<MinusOutlined />}
                        onClick={() => onClick(record.title)}
                    />
                )
            }
        }
    ]
}